#include "HX711.h"                    // Biblioteca HX711
#include "ThingSpeak.h"
#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>
 
#define DOUT  D7                      // HX711 DATA OUT
#define CLK  D5                       // HX711 SCK IN 

#define RED_LED  D3                   // Led
#define GREEN_LED  D2                 // Led

#ifndef STASSID
#define STASSID "SSID"
#define STAPSK  "SENHA"
#endif

WiFiClient client;
HTTPClient http;

HX711 scale;          // define instancia balança HX711
float calibration_factor = 55130;
float minWeight = 0.1;

unsigned long myChannelNumber = 0000000;//NUMERO DO CANAL
const char * myWriteAPIKey = "AAAAAAAAAAAA";//CHAVE DO CANAL

void setup() {
  Serial.begin(9600);         // monitor serial 9600 Bps
  Serial.println();
  Serial.println("");
  
  setupWiFi();                // configura o WiFi  
  setupScale();               // configura a balança
  
  ThingSpeak.begin(client);

  pinMode(RED_LED, OUTPUT);
  pinMode(GREEN_LED, OUTPUT);
  digitalWrite(RED_LED, HIGH);
  digitalWrite(GREEN_LED, HIGH);
}

void setupWiFi () {
  Serial.print("Conectando no WiFi");
  WiFi.begin(STASSID, STAPSK);
    
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Conectado! IP: ");
  Serial.print(WiFi.localIP());
  Serial.println("");
}

void setupScale () {
  scale.begin(DOUT, CLK);      // inicializa a balança
  scale.set_scale();           // configura a escala da Balança
  resetScale();                // zera a Balança
}

void resetScale () {
  Serial.println();
  scale.tare();
  Serial.println("Balança Zerada ");
}

void sendSmsMessage () {
  if(WiFi.status() == WL_CONNECTED){
    Serial.println("wifi ok ");
    if(http.begin(client, "http://api.facilitamovel.com.br/api/simpleSend.ft?user=USUARIO&password=SENHA&destinatario=NUMERO_COM_DDD&externalkey=123&msg=O%20comedouro%20necessita%20de%20reposição.")) {
      int httpCode = http.GET();
      Serial.println("Status mensagem: " + httpCode);      
      http.end();
    }
  } else {
    Serial.println("Sem conexão");
  }
  Serial.println("Mensagem enviada");
}

void sendDataThingSpeak (float weight) {
  ThingSpeak.setField(1, weight);
  int reponse = ThingSpeak.writeFields(myChannelNumber, myWriteAPIKey);

  if(reponse == 200){
    Serial.println("Channel update successful.");
  }
  else{
    Serial.println("Problem updating channel. HTTP error code " + String(reponse));
  }
}

void loop() {
  scale.set_scale(calibration_factor);
  float weight = scale.get_units();
  Serial.println(weight,3);
  
  bool weightOk = weight >= minWeight;
  if (weightOk){
    digitalWrite(RED_LED, LOW);
    digitalWrite(GREEN_LED, HIGH);
  } else {
    digitalWrite(RED_LED, HIGH);
    digitalWrite(GREEN_LED, LOW);
    sendSmsMessage();
  } 
  
  sendDataThingSpeak(weight);  
   
  delay(30000);
  
  if (Serial.available()) {
    char serialRead = Serial.read();
    if (serialRead == 't') resetScale();          // t = zera a Balança
  }
}
